==> Dressing_1.0.1.202504112333-23.jar: src/dressing/ui/util/NumberField.java <==
package dressing.ui.util;

import org.eclipse.jface.viewers.CellEditor.LayoutData;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Layout;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Text;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.custom.CTabFolder;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.layout.FormLayout;
import org.eclipse.swt.layout.FormData;
import org.eclipse.swt.layout.FormAttachment;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;

public class NumberField{
	double maximum=10000;
	double minimum=1;
	double content=minimum;
	
	private Text text;
	
	public Text getText() {
		return text;
	}

	public void setText(Text text) {
		this.text = text;
	}

	public double getMaximum() {
		return maximum;
	}

	public void setMaximum(double maximum2) {
		this.maximum = maximum2;
	}

	public double getMinimum() {
		return minimum;
	}

	public void setMinimum(double minimum2) {
		this.minimum = minimum2;
	}

	public double getContent() {
		return content;
	}

	public void setContent(double d) {
		this.content = d;
	}
	/**
	 * Create the composite.
	 * @param parent
	 * @param style
	 * @wbp.parser.entryPoint
	 */



	public NumberField(Composite parent, int style) {
//		super(parent, SWT.BORDER);
//		setSize(259, 37);

//		setLayout(new FormLayout());
//		text = new Text(this, SWT.BORDER);
//		text.setEditable(true);
//		FormData fd_text = new FormData();
//		fd_text.top = new FormAttachment(0);
//		fd_text.left = new FormAttachment(0);
//		text.setLayoutData(fd_text);
//		
//		Button btnNewButton = new Button(this, SWT.BORDER | SWT.FLAT | SWT.ARROW|SWT.TOP|SWT.CURSOR_SIZENESW);
//		fd_text.right = new FormAttachment(100, -22);
//		FormData fd_btnNewButton = new FormData();
//		fd_btnNewButton.left = new FormAttachment(text, 1);
//		fd_btnNewButton.right = new FormAttachment(100);
//		fd_btnNewButton.bottom = new FormAttachment(100, -19);
//		fd_btnNewButton.top = new FormAttachment(0);
//		btnNewButton.setLayoutData(fd_btnNewButton);
//		Button btnNewButton_1 = new Button(this, SWT.BORDER | SWT.FLAT | SWT.ARROW|SWT.BOTTOM|SWT.CURSOR_SIZENESW);
//		fd_text.bottom = new FormAttachment(btnNewButton_1, 0, SWT.BOTTOM);
//		btnNewButton_1.addSelectionListener(new SelectionAdapter() {
//			@Override
//			public void widgetSelected(SelectionEvent e) {
//			}
//		});
//		FormData fd_btnNewButton_1 = new FormData();
//		fd_btnNewButton_1.left = new FormAttachment(text, 1);
//		fd_btnNewButton_1.right = new FormAttachment(100);
//		fd_btnNewButton_1.top = new FormAttachment(0, 20);
//		fd_btnNewButton_1.bottom = new FormAttachment(100);
//		btnNewButton_1.setLayoutData(fd_btnNewButton_1);


	
	}
	public Text ConvertTextToNumberField(Composite parent, int Style) {
		
		this.text= new Text(parent, Style);
		this.text.addListener(SWT.Verify, new Listener() {
		      public void handleEvent(Event e) {
		       try
		       {
		    	     String string = e.text;
		    	     string.replace(" ", "");
		    	     string.replace(",", ".");
		        char[] chars = new char[string.length()];
		        string.getChars(0, chars.length, chars, 0);
		     
		        for (int i = 0; i < chars.length; i++) {
		          if (!('0' <= chars[i] && chars[i] <= '9')||!(chars[i]=='.'||chars[i]==',')) {
		            e.doit = false;
		            return;
		          }
		        }
		        if(Double.parseDouble(text.getText())<0) {
		        	e.doit = false;
		        }
		        text.setData(Double.parseDouble(text.getText()));
		       if(getContent()>getMaximum()||getContent()<getMinimum()) {
		    	   e.doit=false;
		       }
		       }catch(StringIndexOutOfBoundsException e1)
		       {
		    	   System.out.println(e1.getStackTrace());
		    	   e1.addSuppressed(e1);
		    	   
		       }catch(Exception e2){
		    	   System.out.println(e2.getStackTrace());
		       }
		        
		      }
		    });
		return this.text;
	
	}
}

==> Dressing_1.0.1.202505290913-1096.jar: src/dressing/ui/util/NumberField.java <==
package dressing.ui.util;

import org.eclipse.jface.viewers.CellEditor.LayoutData;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Layout;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Text;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.custom.CTabFolder;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.layout.FormLayout;
import org.eclipse.swt.layout.FormData;
import org.eclipse.swt.layout.FormAttachment;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;

public final class NumberField{
	double maximum=100000000.0;
	double minimum=-100000000.0;
	double content=0;
	
	private Text text;
	
	public Text getText() {
		return text;
	}


	public double getMaximum() {
		return maximum;
	}

	public void setMaximum(double maximum2) {
		this.maximum = maximum2;
	}

	public double getMinimum() {
		return minimum;
	}

	public void setMinimum(double minimum2) {
		this.minimum = minimum2;
	}

	public double getContent() {
		return content;
	}

	public void setContent(double d) {
		this.content = d;
		this.text.setText(String.valueOf(d));
	}
	/**
	 * Create the composite.
	 * @param parent
	 * @param style
	 * @wbp.parser.entryPoint
	 */



	public NumberField(Composite parent, int style) {
//		super(parent, SWT.BORDER);
//		setSize(259, 37);

//		setLayout(new FormLayout());
//		text = new Text(this, SWT.BORDER);
//		text.setEditable(true);
//		FormData fd_text = new FormData();
//		fd_text.top = new FormAttachment(0);
//		fd_text.left = new FormAttachment(0);
//		text.setLayoutData(fd_text);
//		
//		Button btnNewButton = new Button(this, SWT.BORDER | SWT.FLAT | SWT.ARROW|SWT.TOP|SWT.CURSOR_SIZENESW);
//		fd_text.right = new FormAttachment(100, -22);
//		FormData fd_btnNewButton = new FormData();
//		fd_btnNewButton.left = new FormAttachment(text, 1);
//		fd_btnNewButton.right = new FormAttachment(100);
//		fd_btnNewButton.bottom = new FormAttachment(100, -19);
//		fd_btnNewButton.top = new FormAttachment(0);
//		btnNewButton.setLayoutData(fd_btnNewButton);
//		Button btnNewButton_1 = new Button(this, SWT.BORDER | SWT.FLAT | SWT.ARROW|SWT.BOTTOM|SWT.CURSOR_SIZENESW);
//		fd_text.bottom = new FormAttachment(btnNewButton_1, 0, SWT.BOTTOM);
//		btnNewButton_1.addSelectionListener(new SelectionAdapter() {
//			@Override
//			public void widgetSelected(SelectionEvent e) {
//			}
//		});
//		FormData fd_btnNewButton_1 = new FormData();
//		fd_btnNewButton_1.left = new FormAttachment(text, 1);
//		fd_btnNewButton_1.right = new FormAttachment(100);
//		fd_btnNewButton_1.top = new FormAttachment(0, 20);
//		fd_btnNewButton_1.bottom = new FormAttachment(100);
//		btnNewButton_1.setLayoutData(fd_btnNewButton_1);

		this.text=ConvertTextToNumberField(parent, style);
	
	}
	public Text ConvertTextToNumberField(Composite parent, int Style) {
		
		this.text= new Text(parent, Style);
		this.text.addListener(SWT.Verify, new Listener() {
		      public void handleEvent(Event e) {
		       try
		       {
		    	     String string = e.text;
		    	     string.replace(" ", "");
		    	     string.replace(",", ".");
		        char[] chars = new char[string.length()];
		        string.getChars(0, chars.length, chars, 0);
		        if(NumberField.this.getText().getText().contains(".")&&(string.contains(".")||string.contains(","))) {
		        	 e.doit = false;
			            return;
		        }
		        for (int i = 0; i < chars.length; i++) {
		          if (!('0' <= chars[i] && chars[i] <= '9')&&!(chars[i]=='.'||chars[i]==',')&& !(i==0 && chars[i]=='-')) {
		            e.doit = false;
		            return;
		          }
		        }
		        if(Double.parseDouble(text.getText())<getMinimum()) {
		        	e.doit = false;
		        }
		        text.setData(Double.parseDouble(text.getText()));
		       if((double) text.getData()>getMaximum()||(double) text.getData()<getMinimum()) {
		    	   e.doit=false;
		       }
		       }catch(StringIndexOutOfBoundsException e1)
		       {
		    	   e.doit=false;
		    	   System.out.println(e1.getMessage());
		    	   e1.addSuppressed(e1);
		    	   
		       }catch(Exception e2){
		    	   System.out.println(e2.getMessage());
		       }
		        
		      }
		    });
		return this.text;
	
	}
	
	public static Text createNumberField(Composite parent, int style) {
		return new NumberField(parent, style).getText();
	}
}
